@@ -7,6 +7,8 @@ from django.utils.html import format_html
 from django_table_sort.columns import TableColumn
 from django_table_sort.columns import TableExtraColumn
 
+ALL_FIELDS = ["__all__"]
+
 
 class TableSort:
     r"""
@@ -14,8 +16,21 @@ class TableSort:
 
     :param request: current ``HttpRequest`` to get the url lookups to create the links.
     :param object_list: ``QuerySet`` or ``list`` to fill the table.
-    :param column_names: ``dict`` containing the pair {field_name: field_header}, this is used to set which field will be displayed and the proper headers. If no column_names are set and the object_list is a ``Queryset``, the all the fields in the Queryset's model will be used, and as the header their verbose_name.
-    :param sort_key_name: ``str`` for the key name that will be used to create the sort lookup in the urls.
+    :param fields: ``list`` This field sets which fields should be displayed, the
+    default value is ['__all__'] that will display all the fields in the model
+    and the verbose_name of them as the header of the columns. You can use the
+    column_names param to customize the headers.
+    :param exclude: ``list`` Similar to the fields param, defines which fields
+    should be excluded, all the field that aren't in the exclude list will be displayed.
+    If no column_names are set and the object_list is a ``Queryset``, the all the
+    fields in the Queryset's model will be used, and as the header their verbose_name.
+    :param column_names: ``dict`` containing the pair {field_name: field_header},
+    this field has two uses, if you provide a ``list`` of X items this field will
+    set which field will be displayed and the proper headers, if you provide
+    a ``Queryset`` instead this field will define how the columns header will
+    be displayed.
+    :param sort_key_name: ``str`` for the key name that will be used to create
+    the sort lookup in the urls.
     :param table_css_clases: class to be applied to the table.
     :param table_id: ``str`` for the id of the generated tabled.
     :param **kwargs:
@@ -24,14 +39,20 @@ class TableSort:
     :Keyword Arguments:
         * *show_primary_key* (``bool``) --
           Set if the primary key of the model should be displayed, default=``False``.
-        * *added_columns* (``dict``) --
-          Extra columns to show in the table, should be a ``dict`` object having the pair {(field_identifier,field_header):callable_function}. Note that field_identifier is to mark a difference to the models fields and callable_function needs to be a function that will receive an object and return an str to print in the table column
+        * *added_columns* (``list``) --
+          Extra columns to show in the table, should be a ``list`` object
+          having the pair ((field_identifier, field_header), callable_function).
+          Note that field_identifier is to mark a difference to the models fields
+          and callable_function needs to be a function that will receive an
+          object and return an str to print in the table column.
     """
 
     def __init__(
         self,
         request: HttpRequest,
         object_list: QuerySet | list,
+        fields: list = ALL_FIELDS,
+        exclude: list = None,
         column_names: None | dict[str, str] = None,
         sort_key_name: str = "o",
         table_css_clases: str = "table",
@@ -44,10 +65,34 @@ class TableSort:
         self.table_css_clases = table_css_clases
         self.table_id = table_id
         self.kwargs = kwargs
-        if column_names is None and isinstance(object_list, QuerySet):
+        column_names = column_names or {}
+        if exclude is not None and isinstance(object_list, QuerySet):
+            fields = [
+                field
+                for field in object_list.model._meta.get_fields()
+                if field.name not in exclude
+            ]
             self.column_names = [
-                TableColumn(field.name, field.verbose_name.title())
-                for field in object_list.model._meta.fields
+                TableColumn(
+                    field.name, column_names.get(field.name, field.verbose_name.title())
+                )
+                for field in fields
+                if not field.primary_key or kwargs.get("show_primary_key", False)
+            ]
+        elif fields is not None and isinstance(object_list, QuerySet):
+            if fields == ALL_FIELDS:
+                fields = object_list.model._meta.get_fields()
+            else:
+                fields = [
+                    field
+                    for field in object_list.model._meta.get_fields()
+                    if field.name in fields
+                ]
+            self.column_names = [
+                TableColumn(
+                    field.name, column_names.get(field.name, field.verbose_name.title())
+                )
+                for field in fields
                 if not field.primary_key or kwargs.get("show_primary_key", False)
             ]
         elif column_names is not None:
@@ -151,10 +196,17 @@ class TableSort:
                     <div>
                         {column_name}
                         <div class="sort-options {show_sort}">
-                            <a href="?{sort_url}" role="button" title="{ordering_text}"><i class="fa-solid fa-sort{sort_direction}"></i></a>
+                            <a href="?{sort_url}" role="button" title="{ordering_text}">
+                                <i class="fa-solid fa-sort{sort_direction}"></i>
+                            </a>
                         </div>
                         <div class="sort-options">
-                            <a href="?{url_start}" class="{hide_cancel}" role="button" title="Remove sort"><i class="fa-solid fa-ban"></i></a>
+                            <a href="?{url_start}"
+                                class="{hide_cancel}"
+                                role="button"
+                                title="Remove sort">
+                                    <i class="fa-solid fa-ban"></i>
+                            </a>
                         </div>
                     </div>
                 </th>""".format(  # noqa: F522
